from __future__ import absolute_import as _

from ._read import read_plink
from ._testit import test

__version__ = "1.2.28"


def example_file_prefix():
    r"""Data files prefix."""
    import os
    p = __import__('pandas_plink').__path__[0]
    return os.path.join(p, 'test', 'data_files', 'data')


__all__ = [
    "__version__", "test", 'example_file_prefix', 'read_plink'
]



from __future__ import unicode_literals

from os.path import dirname, join, realpath

import pytest
from numpy import array, nan
from numpy.testing import assert_array_equal
from pandas_plink import read_plink


def _ascii_airlock(v):
    if not isinstance(v, bytes):
        v = v.encode()
    return v


def test_read_plink():

    datafiles = join(dirname(realpath(__file__)), 'data_files')
    file_prefix = join(datafiles, 'data')

    (bim, fam, bed) = read_plink(file_prefix)

    assert_array_equal(
        bim.query("chrom=='1' and pos==72515")['snp'], ['rs4030300'])
    assert_array_equal(bim.query("chrom=='1'").shape, [10, 7])
    assert_array_equal(
        fam.query("fid=='Sample_2' and iid=='Sample_2'")["trait"], ['-9'])

    assert_array_equal(bed,
                       array([[2, 2, 1], [2, 1, 2], [nan, nan, nan],
                              [nan, nan, 1], [2, 2, 2], [2, 2, 2], [2, 1, 0],
                              [2, 2, 2], [1, 2, 2], [2, 1, 2]]))


def test_read_plink_prefix_dot():

    with pytest.raises(IOError):
        read_plink('/home/joao/84757.genotypes.norm.renamed')



from os.path import dirname, join, realpath

from cffi import FFI

ffibuilder = FFI()
ffibuilder.set_unicode(False)

ffibuilder.cdef(
    r"""
    int read_bed_chunk(char*, uint64_t, uint64_t,
                       uint64_t, uint64_t,
                       uint64_t, uint64_t,
                       uint64_t*, uint64_t*);
"""
)

dirname(realpath(__file__))
ffibuilder.set_source(
    "pandas_plink.bed_reader",
    r"""
int read_bed_chunk(char*, uint64_t, uint64_t,
                       uint64_t, uint64_t,
                       uint64_t, uint64_t,
                       uint64_t*, uint64_t*);
""",
    sources=[join("pandas_plink", "_bed_reader.c")],
)

if __name__ == "__main__":
    ffibuilder.compile(verbose=True)
